# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class CustomTranslationControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_custom_translation_using_get(self, **kwargs):  # noqa: E501
        """Get end-user Custom Translation configuration (getCustomTranslation)  # noqa: E501

        Fetch the Custom Translation map for the end user. The custom translation is configured in the white labeling parameters. If custom translation translation is defined on the tenant level, it overrides the custom translation of the system level. Similar, if the custom translation is defined on the customer level, it overrides the translation configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_translation_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_translation_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_translation_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_custom_translation_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get end-user Custom Translation configuration (getCustomTranslation)  # noqa: E501

        Fetch the Custom Translation map for the end user. The custom translation is configured in the white labeling parameters. If custom translation translation is defined on the tenant level, it overrides the custom translation of the system level. Similar, if the custom translation is defined on the customer level, it overrides the translation configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_translation_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_translation_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `get_custom_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customTranslation/customTranslation', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomTranslation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_custom_translation_using_post(self, **kwargs):  # noqa: E501
        """Create Or Update Custom Translation (saveCustomTranslation)  # noqa: E501

        Creates or Updates the Custom Translation map.   Request example:   ```json {\"translationMap\":{\"es_ES\":\"{\\\"home\\\":\\\"MyHome\\\"}\"}} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_custom_translation_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomTranslation body:
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_custom_translation_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_custom_translation_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_custom_translation_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Create Or Update Custom Translation (saveCustomTranslation)  # noqa: E501

        Creates or Updates the Custom Translation map.   Request example:   ```json {\"translationMap\":{\"es_ES\":\"{\\\"home\\\":\\\"MyHome\\\"}\"}} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_custom_translation_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomTranslation body:
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_custom_translation_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `save_custom_translation`")  # noqa: E501
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customTranslation/customTranslation', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomTranslation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_custom_translation(self, locale_code, **kwargs):  # noqa: E501
        """Delete Custom Translation for specified locale (deleteCustomTranslation)  # noqa: E501

        Delete entire custom translation settings for end-user  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def delete_custom_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Delete Custom Translation for specified locale (deleteCustomTranslation)  # noqa: E501

        Delete entire custom translation settings for end-user  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_custom_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `delete_custom_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/custom/{localeCode}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_custom_translation_key(self, locale_code, key_path, **kwargs):  # noqa: E501
        """Delete specified key of Custom Translation (deleteCustomTranslationKey)   # noqa: E501

        The API call is designed to delete specified key of the custom translation and return as a result parent translation.(e.g. if tenant translation for key is 'value1' and customer translation is 'value2' then by deletinf key onn customer level you will get 'value1' in response)   Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_translation_key(locale_code, key_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str key_path: A string value representing key of the custom translation (e.g. 'notification.active'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_custom_translation_key_with_http_info(locale_code, key_path, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_custom_translation_key_with_http_info(locale_code, key_path, **kwargs)  # noqa: E501
            return data

    def delete_custom_translation_key_with_http_info(self, locale_code, key_path, **kwargs):  # noqa: E501
        """Delete specified key of Custom Translation (deleteCustomTranslationKey)   # noqa: E501

        The API call is designed to delete specified key of the custom translation and return as a result parent translation.(e.g. if tenant translation for key is 'value1' and customer translation is 'value2' then by deletinf key onn customer level you will get 'value1' in response)   Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_translation_key_with_http_info(locale_code, key_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str key_path: A string value representing key of the custom translation (e.g. 'notification.active'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code', 'key_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_custom_translation_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `delete_custom_translation_key`")  # noqa: E501
        # verify the required parameter 'key_path' is set
        if ('key_path' not in params or
                params['key_path'] is None):
            raise ValueError(
                "Missing the required parameter `key_path` when calling `delete_custom_translation_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501
        if 'key_path' in params:
            path_params['keyPath'] = params['key_path']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/custom/{localeCode}/{keyPath}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_custom_translation(self, body, locale_code, **kwargs):  # noqa: E501
        """Update Custom Translation for specified translation keys only (patchCustomTranslation)  # noqa: E501

        The API call is designed to update the custom translation for specified key only.    Request example:   ```json {\"notification.active\":\"active\"} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_custom_translation(body, locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_custom_translation_with_http_info(body, locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_custom_translation_with_http_info(body, locale_code, **kwargs)  # noqa: E501
            return data

    def patch_custom_translation_with_http_info(self, body, locale_code, **kwargs):  # noqa: E501
        """Update Custom Translation for specified translation keys only (patchCustomTranslation)  # noqa: E501

        The API call is designed to update the custom translation for specified key only.    Request example:   ```json {\"notification.active\":\"active\"} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_custom_translation_with_http_info(body, locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_custom_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError(
                "Missing the required parameter `body` when calling `patch_custom_translation`")  # noqa: E501
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `patch_custom_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/custom/{localeCode}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_custom_translation(self, locale_code, **kwargs):  # noqa: E501
        """Upload Custom Translation (uploadCustomTranslation)  # noqa: E501

        Upload the Custom Translation for specified locale.   Request example:   ```json {\"home\":\"MyHome\"} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_custom_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str file:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def upload_custom_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Upload Custom Translation (uploadCustomTranslation)  # noqa: E501

        Upload the Custom Translation for specified locale.   Request example:   ```json {\"home\":\"MyHome\"} ```  Security check is performed to verify that the user has 'WRITE' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_custom_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str file:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_custom_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `upload_custom_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/custom/{localeCode}/upload', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_merged_custom_translation(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user Custom Translation configuration (getMergedCustomTranslation)  # noqa: E501

        Fetch end-user Custom Translation for specified locale. The custom translation is configured in the white labeling parameters. If custom translation translation is defined on the tenant level, it overrides the custom translation of the system level. Similar, if the custom translation is defined on the customer level, it overrides the translation configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_merged_custom_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_merged_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.get_merged_custom_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def get_merged_custom_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user Custom Translation configuration (getMergedCustomTranslation)  # noqa: E501

        Fetch end-user Custom Translation for specified locale. The custom translation is configured in the white labeling parameters. If custom translation translation is defined on the tenant level, it overrides the custom translation of the system level. Similar, if the custom translation is defined on the customer level, it overrides the translation configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_merged_custom_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: CustomTranslation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_merged_custom_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError(
                "Missing the required parameter `locale_code` when calling `get_merged_custom_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/custom/merged/{localeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomTranslation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class MobileAppControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_mobile_app(self, id, **kwargs):  # noqa: E501
        """Delete Mobile App by ID (deleteMobileApp)  # noqa: E501

        Deletes Mobile App by ID. Referencing non-existing mobile app Id will cause an error.  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_mobile_app(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_mobile_app_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_mobile_app_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_mobile_app_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete Mobile App by ID (deleteMobileApp)  # noqa: E501

        Deletes Mobile App by ID. Referencing non-existing mobile app Id will cause an error.  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_mobile_app_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_mobile_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_mobile_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/mobileApp/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mobile_app_info_by_id(self, id, **kwargs):  # noqa: E501
        """Get mobile info by id (getMobileAppInfoById)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mobile_app_info_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: MobileAppInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_mobile_app_info_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_mobile_app_info_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_mobile_app_info_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get mobile info by id (getMobileAppInfoById)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mobile_app_info_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: MobileAppInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mobile_app_info_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_mobile_app_info_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/mobileApp/info/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MobileAppInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tenant_mobile_app_infos(self, page_size, page, **kwargs):  # noqa: E501
        """Get mobile app infos (getTenantMobileAppInfos)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_mobile_app_infos(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on app's name
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataMobileAppInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tenant_mobile_app_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tenant_mobile_app_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_tenant_mobile_app_infos_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get mobile app infos (getTenantMobileAppInfos)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_mobile_app_infos_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on app's name
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataMobileAppInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tenant_mobile_app_infos" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_tenant_mobile_app_infos`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_tenant_mobile_app_infos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/mobileApp/infos{?pageSize,page,textSearch,sortProperty,sortOrder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataMobileAppInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_mobile_app(self, body, **kwargs):  # noqa: E501
        """Save Or update Mobile app (saveMobileApp)  # noqa: E501

        Create or update the Mobile app. When creating mobile app, platform generates Mobile App Id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created Mobile App Id will be present in the response. Specify existing Mobile App Id to update the mobile app. Referencing non-existing Mobile App Id will cause 'Not Found' error.  Mobile app package name is unique for entire platform setup.    Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_mobile_app(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MobileApp body: (required)
        :param list[object] oauth2_client_ids: A list of entity oauth2 client ids, separated by comma ','
        :return: MobileApp
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_mobile_app_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.save_mobile_app_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def save_mobile_app_with_http_info(self, body, **kwargs):  # noqa: E501
        """Save Or update Mobile app (saveMobileApp)  # noqa: E501

        Create or update the Mobile app. When creating mobile app, platform generates Mobile App Id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created Mobile App Id will be present in the response. Specify existing Mobile App Id to update the mobile app. Referencing non-existing Mobile App Id will cause 'Not Found' error.  Mobile app package name is unique for entire platform setup.    Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_mobile_app_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MobileApp body: (required)
        :param list[object] oauth2_client_ids: A list of entity oauth2 client ids, separated by comma ','
        :return: MobileApp
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'oauth2_client_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_mobile_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `save_mobile_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'oauth2_client_ids' in params and params.get('oauth2_client_ids') is not None:
            query_params.append(('oauth2ClientIds', params['oauth2_client_ids']))  # noqa: E501
            collection_formats['oauth2ClientIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/mobileApp', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MobileApp',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_oauth2_clients(self, body, id, **kwargs):  # noqa: E501
        """Update oauth2 clients (updateOauth2Clients)  # noqa: E501

        Update oauth2 clients of the specified mobile app.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_oauth2_clients(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_oauth2_clients_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_oauth2_clients_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def update_oauth2_clients_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Update oauth2 clients (updateOauth2Clients)  # noqa: E501

        Update oauth2 clients of the specified mobile app.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_oauth2_clients_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_oauth2_clients" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_oauth2_clients`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_oauth2_clients`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/mobileApp/{id}/oauth2Clients', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class KeyFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'EntityKey',
        'value_type': 'str',
        'predicate': 'OneOfKeyFilterPredicate'
    }

    attribute_map = {
        'key': 'key',
        'value_type': 'valueType',
        'predicate': 'predicate'
    }

    def __init__(self, key=None, value_type=None, predicate=None):  # noqa: E501
        """KeyFilter - a model defined in Swagger"""  # noqa: E501
        self._key = None
        self._value_type = None
        self._predicate = None
        self.discriminator = None
        if key is not None:
            self.key = key
        if value_type is not None:
            self.value_type = value_type
        if predicate is not None:
            self.predicate = predicate

    @property
    def key(self):
        """Gets the key of this KeyFilter.  # noqa: E501


        :return: The key of this KeyFilter.  # noqa: E501
        :rtype: EntityKey
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this KeyFilter.


        :param key: The key of this KeyFilter.  # noqa: E501
        :type: EntityKey
        """

        self._key = key

    @property
    def value_type(self):
        """Gets the value_type of this KeyFilter.  # noqa: E501


        :return: The value_type of this KeyFilter.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this KeyFilter.


        :param value_type: The value_type of this KeyFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRING", "NUMERIC", "BOOLEAN", "DATE_TIME"]  # noqa: E501
        if value_type not in allowed_values:
            raise ValueError(
                "Invalid value for `value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(value_type, allowed_values)
            )

        self._value_type = value_type

    @property
    def predicate(self):
        """Gets the predicate of this KeyFilter.  # noqa: E501


        :return: The predicate of this KeyFilter.  # noqa: E501
        :rtype: OneOfKeyFilterPredicate
        """
        return self._predicate

    @predicate.setter
    def predicate(self, predicate):
        """Sets the predicate of this KeyFilter.


        :param predicate: The predicate of this KeyFilter.  # noqa: E501
        :type: OneOfKeyFilterPredicate
        """

        self._predicate = predicate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KeyFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeyFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class OAuth2ClientInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'OAuth2ClientId',
        'created_time': 'int',
        'title': 'str',
        'provider_name': 'str',
        'platforms': 'list[str]',
        'name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'title': 'title',
        'provider_name': 'providerName',
        'platforms': 'platforms',
        'name': 'name'
    }

    def __init__(self, id=None, created_time=None, title=None, provider_name=None, platforms=None, name=None):  # noqa: E501
        """OAuth2ClientInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._title = None
        self._provider_name = None
        self._platforms = None
        self._name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if title is not None:
            self.title = title
        if provider_name is not None:
            self.provider_name = provider_name
        if platforms is not None:
            self.platforms = platforms
        if name is not None:
            self.name = name

    @property
    def id(self):
        """Gets the id of this OAuth2ClientInfo.  # noqa: E501


        :return: The id of this OAuth2ClientInfo.  # noqa: E501
        :rtype: OAuth2ClientId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OAuth2ClientInfo.


        :param id: The id of this OAuth2ClientInfo.  # noqa: E501
        :type: OAuth2ClientId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this OAuth2ClientInfo.  # noqa: E501


        :return: The created_time of this OAuth2ClientInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this OAuth2ClientInfo.


        :param created_time: The created_time of this OAuth2ClientInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def title(self):
        """Gets the title of this OAuth2ClientInfo.  # noqa: E501

        Oauth2 client registration title (e.g. My google)  # noqa: E501

        :return: The title of this OAuth2ClientInfo.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this OAuth2ClientInfo.

        Oauth2 client registration title (e.g. My google)  # noqa: E501

        :param title: The title of this OAuth2ClientInfo.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def provider_name(self):
        """Gets the provider_name of this OAuth2ClientInfo.  # noqa: E501

        Oauth2 client provider name (e.g. Google)  # noqa: E501

        :return: The provider_name of this OAuth2ClientInfo.  # noqa: E501
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this OAuth2ClientInfo.

        Oauth2 client provider name (e.g. Google)  # noqa: E501

        :param provider_name: The provider_name of this OAuth2ClientInfo.  # noqa: E501
        :type: str
        """

        self._provider_name = provider_name

    @property
    def platforms(self):
        """Gets the platforms of this OAuth2ClientInfo.  # noqa: E501

        List of platforms for which usage of the OAuth2 client is allowed (empty for all allowed)  # noqa: E501

        :return: The platforms of this OAuth2ClientInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this OAuth2ClientInfo.

        List of platforms for which usage of the OAuth2 client is allowed (empty for all allowed)  # noqa: E501

        :param platforms: The platforms of this OAuth2ClientInfo.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["WEB", "ANDROID", "IOS"]  # noqa: E501
        if not set(platforms).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `platforms` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(platforms) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._platforms = platforms

    @property
    def name(self):
        """Gets the name of this OAuth2ClientInfo.  # noqa: E501


        :return: The name of this OAuth2ClientInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OAuth2ClientInfo.


        :param name: The name of this OAuth2ClientInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OAuth2ClientInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2ClientInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class VersionCreationResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version': 'EntityVersion',
        'added': 'int',
        'modified': 'int',
        'removed': 'int',
        'error': 'str',
        'done': 'bool'
    }

    attribute_map = {
        'version': 'version',
        'added': 'added',
        'modified': 'modified',
        'removed': 'removed',
        'error': 'error',
        'done': 'done'
    }

    def __init__(self, version=None, added=None, modified=None, removed=None, error=None, done=None):  # noqa: E501
        """VersionCreationResult - a model defined in Swagger"""  # noqa: E501
        self._version = None
        self._added = None
        self._modified = None
        self._removed = None
        self._error = None
        self._done = None
        self.discriminator = None
        if version is not None:
            self.version = version
        if added is not None:
            self.added = added
        if modified is not None:
            self.modified = modified
        if removed is not None:
            self.removed = removed
        if error is not None:
            self.error = error
        if done is not None:
            self.done = done

    @property
    def version(self):
        """Gets the version of this VersionCreationResult.  # noqa: E501


        :return: The version of this VersionCreationResult.  # noqa: E501
        :rtype: EntityVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this VersionCreationResult.


        :param version: The version of this VersionCreationResult.  # noqa: E501
        :type: EntityVersion
        """

        self._version = version

    @property
    def added(self):
        """Gets the added of this VersionCreationResult.  # noqa: E501


        :return: The added of this VersionCreationResult.  # noqa: E501
        :rtype: int
        """
        return self._added

    @added.setter
    def added(self, added):
        """Sets the added of this VersionCreationResult.


        :param added: The added of this VersionCreationResult.  # noqa: E501
        :type: int
        """

        self._added = added

    @property
    def modified(self):
        """Gets the modified of this VersionCreationResult.  # noqa: E501


        :return: The modified of this VersionCreationResult.  # noqa: E501
        :rtype: int
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this VersionCreationResult.


        :param modified: The modified of this VersionCreationResult.  # noqa: E501
        :type: int
        """

        self._modified = modified

    @property
    def removed(self):
        """Gets the removed of this VersionCreationResult.  # noqa: E501


        :return: The removed of this VersionCreationResult.  # noqa: E501
        :rtype: int
        """
        return self._removed

    @removed.setter
    def removed(self, removed):
        """Sets the removed of this VersionCreationResult.


        :param removed: The removed of this VersionCreationResult.  # noqa: E501
        :type: int
        """

        self._removed = removed

    @property
    def error(self):
        """Gets the error of this VersionCreationResult.  # noqa: E501


        :return: The error of this VersionCreationResult.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this VersionCreationResult.


        :param error: The error of this VersionCreationResult.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def done(self):
        """Gets the done of this VersionCreationResult.  # noqa: E501


        :return: The done of this VersionCreationResult.  # noqa: E501
        :rtype: bool
        """
        return self._done

    @done.setter
    def done(self, done):
        """Sets the done of this VersionCreationResult.


        :param done: The done of this VersionCreationResult.  # noqa: E501
        :type: bool
        """

        self._done = done

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VersionCreationResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionCreationResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class MobileAppVersionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min_version': 'str',
        'min_version_release_notes': 'str',
        'latest_version': 'str',
        'latest_version_release_notes': 'str'
    }

    attribute_map = {
        'min_version': 'minVersion',
        'min_version_release_notes': 'minVersionReleaseNotes',
        'latest_version': 'latestVersion',
        'latest_version_release_notes': 'latestVersionReleaseNotes'
    }

    def __init__(self, min_version=None, min_version_release_notes=None, latest_version=None, latest_version_release_notes=None):  # noqa: E501
        """MobileAppVersionInfo - a model defined in Swagger"""  # noqa: E501
        self._min_version = None
        self._min_version_release_notes = None
        self._latest_version = None
        self._latest_version_release_notes = None
        self.discriminator = None
        if min_version is not None:
            self.min_version = min_version
        if min_version_release_notes is not None:
            self.min_version_release_notes = min_version_release_notes
        if latest_version is not None:
            self.latest_version = latest_version
        if latest_version_release_notes is not None:
            self.latest_version_release_notes = latest_version_release_notes

    @property
    def min_version(self):
        """Gets the min_version of this MobileAppVersionInfo.  # noqa: E501

        Minimum supported version  # noqa: E501

        :return: The min_version of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._min_version

    @min_version.setter
    def min_version(self, min_version):
        """Sets the min_version of this MobileAppVersionInfo.

        Minimum supported version  # noqa: E501

        :param min_version: The min_version of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._min_version = min_version

    @property
    def min_version_release_notes(self):
        """Gets the min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501

        Release notes of minimum supported version  # noqa: E501

        :return: The min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._min_version_release_notes

    @min_version_release_notes.setter
    def min_version_release_notes(self, min_version_release_notes):
        """Sets the min_version_release_notes of this MobileAppVersionInfo.

        Release notes of minimum supported version  # noqa: E501

        :param min_version_release_notes: The min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._min_version_release_notes = min_version_release_notes

    @property
    def latest_version(self):
        """Gets the latest_version of this MobileAppVersionInfo.  # noqa: E501

        Latest supported version  # noqa: E501

        :return: The latest_version of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._latest_version

    @latest_version.setter
    def latest_version(self, latest_version):
        """Sets the latest_version of this MobileAppVersionInfo.

        Latest supported version  # noqa: E501

        :param latest_version: The latest_version of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._latest_version = latest_version

    @property
    def latest_version_release_notes(self):
        """Gets the latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501

        Release notes of latest supported version  # noqa: E501

        :return: The latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._latest_version_release_notes

    @latest_version_release_notes.setter
    def latest_version_release_notes(self, latest_version_release_notes):
        """Sets the latest_version_release_notes of this MobileAppVersionInfo.

        Release notes of latest supported version  # noqa: E501

        :param latest_version_release_notes: The latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._latest_version_release_notes = latest_version_release_notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MobileAppVersionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileAppVersionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.key_filter_predicate import KeyFilterPredicate  # noqa: F401,E501

class StringFilterPredicate(KeyFilterPredicate):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'operation': 'str',
        'value': 'FilterPredicateValueString',
        'ignore_case': 'bool'
    }
    if hasattr(KeyFilterPredicate, "swagger_types"):
        swagger_types.update(KeyFilterPredicate.swagger_types)

    attribute_map = {
        'operation': 'operation',
        'value': 'value',
        'ignore_case': 'ignoreCase'
    }
    if hasattr(KeyFilterPredicate, "attribute_map"):
        attribute_map.update(KeyFilterPredicate.attribute_map)

    def __init__(self, operation=None, value=None, ignore_case=None, *args, **kwargs):  # noqa: E501
        """StringFilterPredicate - a model defined in Swagger"""  # noqa: E501
        self._operation = None
        self._value = None
        self._ignore_case = None
        self.discriminator = None
        if operation is not None:
            self.operation = operation
        if value is not None:
            self.value = value
        if ignore_case is not None:
            self.ignore_case = ignore_case
        KeyFilterPredicate.__init__(self, *args, **kwargs)

    @property
    def operation(self):
        """Gets the operation of this StringFilterPredicate.  # noqa: E501


        :return: The operation of this StringFilterPredicate.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this StringFilterPredicate.


        :param operation: The operation of this StringFilterPredicate.  # noqa: E501
        :type: str
        """
        allowed_values = ["EQUAL", "NOT_EQUAL", "STARTS_WITH", "ENDS_WITH", "CONTAINS", "NOT_CONTAINS", "IN", "NOT_IN"]  # noqa: E501
        if operation not in allowed_values:
            raise ValueError(
                "Invalid value for `operation` ({0}), must be one of {1}"  # noqa: E501
                .format(operation, allowed_values)
            )

        self._operation = operation

    @property
    def value(self):
        """Gets the value of this StringFilterPredicate.  # noqa: E501


        :return: The value of this StringFilterPredicate.  # noqa: E501
        :rtype: FilterPredicateValueString
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this StringFilterPredicate.


        :param value: The value of this StringFilterPredicate.  # noqa: E501
        :type: FilterPredicateValueString
        """

        self._value = value

    @property
    def ignore_case(self):
        """Gets the ignore_case of this StringFilterPredicate.  # noqa: E501


        :return: The ignore_case of this StringFilterPredicate.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_case

    @ignore_case.setter
    def ignore_case(self, ignore_case):
        """Sets the ignore_case of this StringFilterPredicate.


        :param ignore_case: The ignore_case of this StringFilterPredicate.  # noqa: E501
        :type: bool
        """

        self._ignore_case = ignore_case

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StringFilterPredicate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StringFilterPredicate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SignUpSelfRegistrationParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sign_up_text_message': 'str',
        'captcha_site_key': 'str',
        'captcha_version': 'str',
        'captcha_action': 'str',
        'show_privacy_policy': 'bool',
        'show_terms_of_use': 'bool'
    }

    attribute_map = {
        'sign_up_text_message': 'signUpTextMessage',
        'captcha_site_key': 'captchaSiteKey',
        'captcha_version': 'captchaVersion',
        'captcha_action': 'captchaAction',
        'show_privacy_policy': 'showPrivacyPolicy',
        'show_terms_of_use': 'showTermsOfUse'
    }

    def __init__(self, sign_up_text_message=None, captcha_site_key=None, captcha_version=None, captcha_action=None, show_privacy_policy=None, show_terms_of_use=None):  # noqa: E501
        """SignUpSelfRegistrationParams - a model defined in Swagger"""  # noqa: E501
        self._sign_up_text_message = None
        self._captcha_site_key = None
        self._captcha_version = None
        self._captcha_action = None
        self._show_privacy_policy = None
        self._show_terms_of_use = None
        self.discriminator = None
        if sign_up_text_message is not None:
            self.sign_up_text_message = sign_up_text_message
        if captcha_site_key is not None:
            self.captcha_site_key = captcha_site_key
        if captcha_version is not None:
            self.captcha_version = captcha_version
        if captcha_action is not None:
            self.captcha_action = captcha_action
        if show_privacy_policy is not None:
            self.show_privacy_policy = show_privacy_policy
        if show_terms_of_use is not None:
            self.show_terms_of_use = show_terms_of_use

    @property
    def sign_up_text_message(self):
        """Gets the sign_up_text_message of this SignUpSelfRegistrationParams.  # noqa: E501

        The text message to appear on login form  # noqa: E501

        :return: The sign_up_text_message of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: str
        """
        return self._sign_up_text_message

    @sign_up_text_message.setter
    def sign_up_text_message(self, sign_up_text_message):
        """Sets the sign_up_text_message of this SignUpSelfRegistrationParams.

        The text message to appear on login form  # noqa: E501

        :param sign_up_text_message: The sign_up_text_message of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: str
        """

        self._sign_up_text_message = sign_up_text_message

    @property
    def captcha_site_key(self):
        """Gets the captcha_site_key of this SignUpSelfRegistrationParams.  # noqa: E501

        Captcha site key for 'I'm not a robot' validation  # noqa: E501

        :return: The captcha_site_key of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: str
        """
        return self._captcha_site_key

    @captcha_site_key.setter
    def captcha_site_key(self, captcha_site_key):
        """Sets the captcha_site_key of this SignUpSelfRegistrationParams.

        Captcha site key for 'I'm not a robot' validation  # noqa: E501

        :param captcha_site_key: The captcha_site_key of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: str
        """

        self._captcha_site_key = captcha_site_key

    @property
    def captcha_version(self):
        """Gets the captcha_version of this SignUpSelfRegistrationParams.  # noqa: E501

        Captcha version ('v2' = Challenge: display checkbox, 'v3' = Score based)  # noqa: E501

        :return: The captcha_version of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: str
        """
        return self._captcha_version

    @captcha_version.setter
    def captcha_version(self, captcha_version):
        """Sets the captcha_version of this SignUpSelfRegistrationParams.

        Captcha version ('v2' = Challenge: display checkbox, 'v3' = Score based)  # noqa: E501

        :param captcha_version: The captcha_version of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: str
        """

        self._captcha_version = captcha_version

    @property
    def captcha_action(self):
        """Gets the captcha_action of this SignUpSelfRegistrationParams.  # noqa: E501

        Optional action name used for logging (for captcha version 'v3' only)  # noqa: E501

        :return: The captcha_action of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: str
        """
        return self._captcha_action

    @captcha_action.setter
    def captcha_action(self, captcha_action):
        """Sets the captcha_action of this SignUpSelfRegistrationParams.

        Optional action name used for logging (for captcha version 'v3' only)  # noqa: E501

        :param captcha_action: The captcha_action of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: str
        """

        self._captcha_action = captcha_action

    @property
    def show_privacy_policy(self):
        """Gets the show_privacy_policy of this SignUpSelfRegistrationParams.  # noqa: E501

        Show or hide 'Privacy Policy'  # noqa: E501

        :return: The show_privacy_policy of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_privacy_policy

    @show_privacy_policy.setter
    def show_privacy_policy(self, show_privacy_policy):
        """Sets the show_privacy_policy of this SignUpSelfRegistrationParams.

        Show or hide 'Privacy Policy'  # noqa: E501

        :param show_privacy_policy: The show_privacy_policy of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: bool
        """

        self._show_privacy_policy = show_privacy_policy

    @property
    def show_terms_of_use(self):
        """Gets the show_terms_of_use of this SignUpSelfRegistrationParams.  # noqa: E501

        Show or hide 'Terms of Use'  # noqa: E501

        :return: The show_terms_of_use of this SignUpSelfRegistrationParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_terms_of_use

    @show_terms_of_use.setter
    def show_terms_of_use(self, show_terms_of_use):
        """Sets the show_terms_of_use of this SignUpSelfRegistrationParams.

        Show or hide 'Terms of Use'  # noqa: E501

        :param show_terms_of_use: The show_terms_of_use of this SignUpSelfRegistrationParams.  # noqa: E501
        :type: bool
        """

        self._show_terms_of_use = show_terms_of_use

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SignUpSelfRegistrationParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignUpSelfRegistrationParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class UserMobileInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user': 'User',
        'store_info': 'StoreInfo',
        'version_info': 'MobileAppVersionInfo',
        'home_dashboard_info': 'HomeDashboardInfo',
        'pages': 'JsonNode'
    }

    attribute_map = {
        'user': 'user',
        'store_info': 'storeInfo',
        'version_info': 'versionInfo',
        'home_dashboard_info': 'homeDashboardInfo',
        'pages': 'pages'
    }

    def __init__(self, user=None, store_info=None, version_info=None, home_dashboard_info=None, pages=None):  # noqa: E501
        """UserMobileInfo - a model defined in Swagger"""  # noqa: E501
        self._user = None
        self._store_info = None
        self._version_info = None
        self._home_dashboard_info = None
        self._pages = None
        self.discriminator = None
        if user is not None:
            self.user = user
        if store_info is not None:
            self.store_info = store_info
        if version_info is not None:
            self.version_info = version_info
        if home_dashboard_info is not None:
            self.home_dashboard_info = home_dashboard_info
        if pages is not None:
            self.pages = pages

    @property
    def user(self):
        """Gets the user of this UserMobileInfo.  # noqa: E501


        :return: The user of this UserMobileInfo.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this UserMobileInfo.


        :param user: The user of this UserMobileInfo.  # noqa: E501
        :type: User
        """

        self._user = user

    @property
    def store_info(self):
        """Gets the store_info of this UserMobileInfo.  # noqa: E501


        :return: The store_info of this UserMobileInfo.  # noqa: E501
        :rtype: StoreInfo
        """
        return self._store_info

    @store_info.setter
    def store_info(self, store_info):
        """Sets the store_info of this UserMobileInfo.


        :param store_info: The store_info of this UserMobileInfo.  # noqa: E501
        :type: StoreInfo
        """

        self._store_info = store_info

    @property
    def version_info(self):
        """Gets the version_info of this UserMobileInfo.  # noqa: E501


        :return: The version_info of this UserMobileInfo.  # noqa: E501
        :rtype: MobileAppVersionInfo
        """
        return self._version_info

    @version_info.setter
    def version_info(self, version_info):
        """Sets the version_info of this UserMobileInfo.


        :param version_info: The version_info of this UserMobileInfo.  # noqa: E501
        :type: MobileAppVersionInfo
        """

        self._version_info = version_info

    @property
    def home_dashboard_info(self):
        """Gets the home_dashboard_info of this UserMobileInfo.  # noqa: E501


        :return: The home_dashboard_info of this UserMobileInfo.  # noqa: E501
        :rtype: HomeDashboardInfo
        """
        return self._home_dashboard_info

    @home_dashboard_info.setter
    def home_dashboard_info(self, home_dashboard_info):
        """Sets the home_dashboard_info of this UserMobileInfo.


        :param home_dashboard_info: The home_dashboard_info of this UserMobileInfo.  # noqa: E501
        :type: HomeDashboardInfo
        """

        self._home_dashboard_info = home_dashboard_info

    @property
    def pages(self):
        """Gets the pages of this UserMobileInfo.  # noqa: E501


        :return: The pages of this UserMobileInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this UserMobileInfo.


        :param pages: The pages of this UserMobileInfo.  # noqa: E501
        :type: JsonNode
        """

        self._pages = pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserMobileInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserMobileInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class RuleNode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RuleNodeId',
        'created_time': 'int',
        'rule_chain_id': 'RuleChainId',
        'type': 'str',
        'name': 'str',
        'debug_mode': 'bool',
        'singleton_mode': 'bool',
        'queue_name': 'str',
        'configuration_version': 'int',
        'external_id': 'RuleNodeId',
        'configuration': 'JsonNode',
        'additional_info': 'JsonNode'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'rule_chain_id': 'ruleChainId',
        'type': 'type',
        'name': 'name',
        'debug_mode': 'debugMode',
        'singleton_mode': 'singletonMode',
        'queue_name': 'queueName',
        'configuration_version': 'configurationVersion',
        'external_id': 'externalId',
        'configuration': 'configuration',
        'additional_info': 'additionalInfo'
    }

    def __init__(self, id=None, created_time=None, rule_chain_id=None, type=None, name=None, debug_mode=None, singleton_mode=None, queue_name=None, configuration_version=None, external_id=None, configuration=None, additional_info=None):  # noqa: E501
        """RuleNode - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._rule_chain_id = None
        self._type = None
        self._name = None
        self._debug_mode = None
        self._singleton_mode = None
        self._queue_name = None
        self._configuration_version = None
        self._external_id = None
        self._configuration = None
        self._additional_info = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if rule_chain_id is not None:
            self.rule_chain_id = rule_chain_id
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if debug_mode is not None:
            self.debug_mode = debug_mode
        if singleton_mode is not None:
            self.singleton_mode = singleton_mode
        if queue_name is not None:
            self.queue_name = queue_name
        if configuration_version is not None:
            self.configuration_version = configuration_version
        if external_id is not None:
            self.external_id = external_id
        if configuration is not None:
            self.configuration = configuration
        if additional_info is not None:
            self.additional_info = additional_info

    @property
    def id(self):
        """Gets the id of this RuleNode.  # noqa: E501


        :return: The id of this RuleNode.  # noqa: E501
        :rtype: RuleNodeId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RuleNode.


        :param id: The id of this RuleNode.  # noqa: E501
        :type: RuleNodeId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this RuleNode.  # noqa: E501

        Timestamp of the rule node creation, in milliseconds  # noqa: E501

        :return: The created_time of this RuleNode.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this RuleNode.

        Timestamp of the rule node creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this RuleNode.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def rule_chain_id(self):
        """Gets the rule_chain_id of this RuleNode.  # noqa: E501


        :return: The rule_chain_id of this RuleNode.  # noqa: E501
        :rtype: RuleChainId
        """
        return self._rule_chain_id

    @rule_chain_id.setter
    def rule_chain_id(self, rule_chain_id):
        """Sets the rule_chain_id of this RuleNode.


        :param rule_chain_id: The rule_chain_id of this RuleNode.  # noqa: E501
        :type: RuleChainId
        """

        self._rule_chain_id = rule_chain_id

    @property
    def type(self):
        """Gets the type of this RuleNode.  # noqa: E501

        Full Java Class Name of the rule node implementation.   # noqa: E501

        :return: The type of this RuleNode.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RuleNode.

        Full Java Class Name of the rule node implementation.   # noqa: E501

        :param type: The type of this RuleNode.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def name(self):
        """Gets the name of this RuleNode.  # noqa: E501

        User defined name of the rule node. Used on UI and for logging.   # noqa: E501

        :return: The name of this RuleNode.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RuleNode.

        User defined name of the rule node. Used on UI and for logging.   # noqa: E501

        :param name: The name of this RuleNode.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def debug_mode(self):
        """Gets the debug_mode of this RuleNode.  # noqa: E501

        Enable/disable debug.   # noqa: E501

        :return: The debug_mode of this RuleNode.  # noqa: E501
        :rtype: bool
        """
        return self._debug_mode

    @debug_mode.setter
    def debug_mode(self, debug_mode):
        """Sets the debug_mode of this RuleNode.

        Enable/disable debug.   # noqa: E501

        :param debug_mode: The debug_mode of this RuleNode.  # noqa: E501
        :type: bool
        """

        self._debug_mode = debug_mode

    @property
    def singleton_mode(self):
        """Gets the singleton_mode of this RuleNode.  # noqa: E501

        Enable/disable singleton mode.   # noqa: E501

        :return: The singleton_mode of this RuleNode.  # noqa: E501
        :rtype: bool
        """
        return self._singleton_mode

    @singleton_mode.setter
    def singleton_mode(self, singleton_mode):
        """Sets the singleton_mode of this RuleNode.

        Enable/disable singleton mode.   # noqa: E501

        :param singleton_mode: The singleton_mode of this RuleNode.  # noqa: E501
        :type: bool
        """

        self._singleton_mode = singleton_mode

    @property
    def queue_name(self):
        """Gets the queue_name of this RuleNode.  # noqa: E501

        Queue name.   # noqa: E501

        :return: The queue_name of this RuleNode.  # noqa: E501
        :rtype: str
        """
        return self._queue_name

    @queue_name.setter
    def queue_name(self, queue_name):
        """Sets the queue_name of this RuleNode.

        Queue name.   # noqa: E501

        :param queue_name: The queue_name of this RuleNode.  # noqa: E501
        :type: str
        """

        self._queue_name = queue_name

    @property
    def configuration_version(self):
        """Gets the configuration_version of this RuleNode.  # noqa: E501

        Version of rule node configuration.   # noqa: E501

        :return: The configuration_version of this RuleNode.  # noqa: E501
        :rtype: int
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """Sets the configuration_version of this RuleNode.

        Version of rule node configuration.   # noqa: E501

        :param configuration_version: The configuration_version of this RuleNode.  # noqa: E501
        :type: int
        """

        self._configuration_version = configuration_version

    @property
    def external_id(self):
        """Gets the external_id of this RuleNode.  # noqa: E501


        :return: The external_id of this RuleNode.  # noqa: E501
        :rtype: RuleNodeId
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this RuleNode.


        :param external_id: The external_id of this RuleNode.  # noqa: E501
        :type: RuleNodeId
        """

        self._external_id = external_id

    @property
    def configuration(self):
        """Gets the configuration of this RuleNode.  # noqa: E501


        :return: The configuration of this RuleNode.  # noqa: E501
        :rtype: JsonNode
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this RuleNode.


        :param configuration: The configuration of this RuleNode.  # noqa: E501
        :type: JsonNode
        """

        self._configuration = configuration

    @property
    def additional_info(self):
        """Gets the additional_info of this RuleNode.  # noqa: E501


        :return: The additional_info of this RuleNode.  # noqa: E501
        :rtype: JsonNode
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this RuleNode.


        :param additional_info: The additional_info of this RuleNode.  # noqa: E501
        :type: JsonNode
        """

        self._additional_info = additional_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class OAuth2ControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_current_o_auth2_info_using_get(self, **kwargs):  # noqa: E501
        """Get current OAuth2 settings (getCurrentOAuth2Info)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_o_auth2_info_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: OAuth2Info
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_current_o_auth2_info_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_current_o_auth2_info_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_current_o_auth2_info_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get current OAuth2 settings (getCurrentOAuth2Info)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_o_auth2_info_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: OAuth2Info
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_o_auth2_info_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OAuth2Info',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_login_processing_url_using_get(self, **kwargs):  # noqa: E501
        """Get OAuth2 log in processing URL (getLoginProcessingUrl)  # noqa: E501

        Returns the URL enclosed in double quotes. After successful authentication with OAuth2 provider, it makes a redirect to this path so that the platform can do further log in processing. This URL may be configured as 'security.oauth2.loginProcessingUrl' property in yml configuration file, or as 'SECURITY_OAUTH2_LOGIN_PROCESSING_URL' env variable. By default it is '/login/oauth2/code/'  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_login_processing_url_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_login_processing_url_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_login_processing_url_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_login_processing_url_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get OAuth2 log in processing URL (getLoginProcessingUrl)  # noqa: E501

        Returns the URL enclosed in double quotes. After successful authentication with OAuth2 provider, it makes a redirect to this path so that the platform can do further log in processing. This URL may be configured as 'security.oauth2.loginProcessingUrl' property in yml configuration file, or as 'SECURITY_OAUTH2_LOGIN_PROCESSING_URL' env variable. By default it is '/login/oauth2/code/'  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_login_processing_url_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_login_processing_url_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/loginProcessingUrl', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_o_auth2_clients_using_post(self, **kwargs):  # noqa: E501
        """Get OAuth2 clients (getOAuth2Clients)  # noqa: E501

        Get the list of OAuth2 clients to log in with, available for such domain scheme (HTTP or HTTPS) (if x-forwarded-proto request header is present - the scheme is known from it) and domain name and port (port may be known from x-forwarded-port header)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_o_auth2_clients_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pkg_name: Mobile application package name, to find OAuth2 clients where there is configured mobile application with such package name
        :param str platform: Platform type to search OAuth2 clients for which the usage with this platform type is allowed in the settings. If platform type is not one of allowable values - it will just be ignored
        :return: list[OAuth2ClientInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_o_auth2_clients_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_o_auth2_clients_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_o_auth2_clients_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Get OAuth2 clients (getOAuth2Clients)  # noqa: E501

        Get the list of OAuth2 clients to log in with, available for such domain scheme (HTTP or HTTPS) (if x-forwarded-proto request header is present - the scheme is known from it) and domain name and port (port may be known from x-forwarded-port header)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_o_auth2_clients_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pkg_name: Mobile application package name, to find OAuth2 clients where there is configured mobile application with such package name
        :param str platform: Platform type to search OAuth2 clients for which the usage with this platform type is allowed in the settings. If platform type is not one of allowable values - it will just be ignored
        :return: list[OAuth2ClientInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pkg_name', 'platform']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_o_auth2_clients_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pkg_name' in params:
            query_params.append(('pkgName', params['pkg_name']))  # noqa: E501
        if 'platform' in params:
            query_params.append(('platform', params['platform']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/oauth2Clients{?pkgName,platform}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OAuth2ClientInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_o_auth2_info_using_post(self, **kwargs):  # noqa: E501
        """Save OAuth2 settings (saveOAuth2Info)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_o_auth2_info_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OAuth2Info body:
        :return: OAuth2Info
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_o_auth2_info_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_o_auth2_info_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_o_auth2_info_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Save OAuth2 settings (saveOAuth2Info)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_o_auth2_info_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OAuth2Info body:
        :return: OAuth2Info
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_o_auth2_info_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/config', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OAuth2Info',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_oauth2_client(self, id, **kwargs):  # noqa: E501
        """Delete oauth2 client (deleteOauth2Client)  # noqa: E501

        Deletes the oauth2 client. Referencing non-existing oauth2 client Id will cause an error.  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_oauth2_client(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_oauth2_client_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_oauth2_client_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_oauth2_client_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete oauth2 client (deleteOauth2Client)  # noqa: E501

        Deletes the oauth2 client. Referencing non-existing oauth2 client Id will cause an error.  Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_oauth2_client_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_oauth2_client" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_oauth2_client`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/client/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_tenant_o_auth2_client_infos(self, page_size, page, **kwargs):  # noqa: E501
        """Get OAuth2 Client infos (findTenantOAuth2ClientInfos)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_tenant_o_auth2_client_infos(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on client's title
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOAuth2ClientInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_tenant_o_auth2_client_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.find_tenant_o_auth2_client_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def find_tenant_o_auth2_client_infos_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get OAuth2 Client infos (findTenantOAuth2ClientInfos)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_tenant_o_auth2_client_infos_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on client's title
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOAuth2ClientInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_tenant_o_auth2_client_infos" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError(
                "Missing the required parameter `page_size` when calling `find_tenant_o_auth2_client_infos`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError(
                "Missing the required parameter `page` when calling `find_tenant_o_auth2_client_infos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/client/infos{?pageSize,page,textSearch,sortProperty,sortOrder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataOAuth2ClientInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_tenant_o_auth2_client_infos_by_ids(self, client_ids, **kwargs):  # noqa: E501
        """Get OAuth2 Client infos By Ids (findTenantOAuth2ClientInfosByIds)  # noqa: E501

        Fetch OAuth2 Client info objects based on the provided ids.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_tenant_o_auth2_client_infos_by_ids(client_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[object] client_ids: A list of oauth2 ids, separated by comma ',' (required)
        :return: list[OAuth2ClientInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_tenant_o_auth2_client_infos_by_ids_with_http_info(client_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.find_tenant_o_auth2_client_infos_by_ids_with_http_info(client_ids, **kwargs)  # noqa: E501
            return data

    def find_tenant_o_auth2_client_infos_by_ids_with_http_info(self, client_ids, **kwargs):  # noqa: E501
        """Get OAuth2 Client infos By Ids (findTenantOAuth2ClientInfosByIds)  # noqa: E501

        Fetch OAuth2 Client info objects based on the provided ids.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_tenant_o_auth2_client_infos_by_ids_with_http_info(client_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[object] client_ids: A list of oauth2 ids, separated by comma ',' (required)
        :return: list[OAuth2ClientInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['client_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_tenant_o_auth2_client_infos_by_ids" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'client_ids' is set
        if ('client_ids' not in params or
                params['client_ids'] is None):
            raise ValueError(
                "Missing the required parameter `client_ids` when calling `find_tenant_o_auth2_client_infos_by_ids`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'client_ids' in params:
            query_params.append(('clientIds', params['client_ids']))  # noqa: E501
            collection_formats['clientIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/client/infos{?clientIds}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OAuth2ClientInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_o_auth2_client_by_id(self, id, **kwargs):  # noqa: E501
        """Get OAuth2 Client by id (getOAuth2ClientById)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_o_auth2_client_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: OAuth2Client
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_o_auth2_client_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_o_auth2_client_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_o_auth2_client_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get OAuth2 Client by id (getOAuth2ClientById)  # noqa: E501

          Available for users with 'SYS_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_o_auth2_client_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: OAuth2Client
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_o_auth2_client_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `get_o_auth2_client_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/oauth2/client/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OAuth2Client',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
